@@ -11,6 +11,10 @@ class ListOption(TypedDict, total=False):
 
     limit: int
 
+    offset: int
+
+    search: str
+
 
 class ModemPayConfig(TypedDict, total=False):
     """
